===============================
Iotronic Lightning-rod Agent
===============================

Python implementation of Lightning-rod Agent, the Stack4Things
board-side probe.

* Free software: Apache 2.0 license
* Website: http://stack4things.unime.it/
* Documentation: http://docs.openstack.org/developer/iotronic_lightningrod
* Source: https://github.com/openstack/iotronic-lightning-rod
* Bugs: https://bugs.launchpad.net/iotronic-lightning-rod


Installation guides
-------------------

* `Raspberry Pi 2/3 <https://github.com/openstack/iotronic-lightning-rod/blob/master/doc/installation/raspberry_pi_3.rst>`_.

* `Ubuntu 16.04 <https://github.com/openstack/iotronic-lightning-rod/blob/master/doc/installation/ubuntu1604.rst>`_.

* Docker:

  * `Raspberry Pi <https://hub.docker.com/r/mdslab/rpi-openstack-iotronic-lightning-rod/>`_.
  * `Debian/Ubuntu <https://hub.docker.com/r/mdslab/openstack-iotronic-lightning-rod/>`_.